@@ -10,7 +10,8 @@ from setuptools_scm.file_finder_git import git_find_files
 
 
 @pytest.fixture
-def wd(wd):
+def wd(wd, monkeypatch):
+    monkeypatch.delenv("HOME", raising=False)
     wd("git init")
     wd("git config user.email test@example.com")
     wd('git config user.name "a test"')
@@ -45,6 +46,7 @@ setup(use_scm_version={"root": "../..",
 
 
 @pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/298")
+@pytest.mark.issue(403)
 def test_file_finder_no_history(wd, caplog):
     file_list = git_find_files(str(wd.cwd))
     assert file_list == []
